@@ -870,7 +870,7 @@ class SymbolSet(object):
         # re-generate each time.
         return self
 
-    def add_features_and_constants(self, X, y, c, x_dim=1, y_dim=1, c_dim=1, x_prob=None,
+    def add_features_and_constants(self, X, y, c=None, x_dim=1, y_dim=1, c_dim=1, x_prob=None,
                                    c_prob=None, x_group=None, feature_name=None):
         self.add_features(X, y, x_dim=x_dim, y_dim=y_dim, x_prob=x_prob, x_group=x_group,
                           feature_name=feature_name, )
@@ -1231,7 +1231,7 @@ class CalculatePrecisionSet(SymbolSet):
 
     def __init__(self, pset, scoring=None, score_pen=(1,), filter_warning=True, cv=1,
                  cal_dim=True, dim_type=None, fuzzy=False, add_coef=True, inter_add=True,
-                 inner_add=False, vector_add=False, n_jobs=1, batch_size=20,
+                 inner_add=False, vector_add=False, out_add=False, flat_add=False, n_jobs=1, batch_size=20,
                  tq=True):
         """
 
@@ -1287,6 +1287,8 @@ class CalculatePrecisionSet(SymbolSet):
         self.inter_add = inter_add
         self.inner_add = inner_add
         self.vector_add = vector_add
+        self.out_add = out_add
+        self.flat_add = flat_add
         self.n_jobs = n_jobs
         self.batch_size = batch_size
         self.tq = tq
@@ -1307,6 +1309,7 @@ class CalculatePrecisionSet(SymbolSet):
                                                   cv=self.cv, refit=self.refit,
                                                   add_coef=self.add_coef, inter_add=self.inter_add,
                                                   inner_add=self.inner_add, vector_add=self.vector_add,
+                                                  out_add=self.out_add, flat_add=self.flat_add,
                                                   scoring=self.scoring, score_pen=self.score_pen,
                                                   filter_warning=self.filter_warning,
                                                   np_maps=self.np_map)
@@ -1334,6 +1337,7 @@ class CalculatePrecisionSet(SymbolSet):
                                                   cv=self.cv, refit=self.refit,
                                                   add_coef=self.add_coef, inter_add=self.inter_add,
                                                   inner_add=self.inner_add, vector_add=self.vector_add,
+                                                  out_add=self.out_add, flat_add=self.flat_add,
                                                   scoring=self.scoring, score_pen=self.score_pen,
                                                   filter_warning=self.filter_warning,
                                                   np_maps=self.np_map)
@@ -1369,7 +1373,7 @@ class CalculatePrecisionSet(SymbolSet):
                                                   self.terminals_and_constants_repr,
                                                   cv=self.cv, refit=self.refit,
                                                   add_coef=False, inter_add=False,
-                                                  inner_add=False, vector_add=False,
+                                                  inner_add=False, vector_add=False, out_add=False, flat_add=False,
                                                   scoring=self.scoring, score_pen=self.score_pen,
                                                   filter_warning=self.filter_warning,
                                                   np_maps=self.np_map)
@@ -1409,6 +1413,7 @@ class CalculatePrecisionSet(SymbolSet):
                                   scoring=self.scoring, score_pen=self.score_pen,
                                   vector_add=self.vector_add,
                                   add_coef=self.add_coef, inter_add=self.inter_add,
+                                  out_add=self.out_add, flat_add=self.flat_add,
                                   inner_add=self.inner_add, np_maps=self.np_map,
                                   filter_warning=self.filter_warning,
                                   dim_maps=self.dim_map, cal_dim=self.cal_dim)
@@ -1418,33 +1423,3 @@ class CalculatePrecisionSet(SymbolSet):
                                      tq=self.tq, batch_size=self.batch_size)
 
         return score_dim_list
-
-# from sklearn.datasets import load_boston
-#
-# data = load_boston()
-# x = data["data"]
-# y = data["target"]
-# # No = Normalizer()
-# # y=y/max(y)
-# # x = No.fit_transform(x)
-# pset = SymbolSet()
-# # self.pset.add_features(x, y, )
-# pset.add_features(x, y, x_group=[[1, 2], [4, 5]])
-# pset.add_constants([6, 3, 4], c_dim=[dless, dless, dless], c_prob=None)
-# pset.add_operations(power_categories=(2, 3, 0.5),
-#                     categories=("Add", "Mul", "Self", "Abs"),
-#                     self_categories=None)
-# cp = CalculatePrecisionSet(pset, scoring=[r2_score, ],
-#                            score_pen=[1, ],
-#                            filter_warning=True)
-# from numpy import random
-#
-# random.seed(1)
-# sl = SymbolTree.genGrow(pset, 3, 4)
-# sl.pre_y = y
-# sl.y_dim = dless
-# expr = compile_context(expr=sl, context=pset.context, gro_ter_con=pset.gro_ter_con)
-# sl.expr = expr
-# pset.add_tree_to_features(sl)
-#
-# assert "new0" in pset.terminals_init_map
