@@ -27,7 +27,8 @@ from featurebox.symbol.functions.dimfunc import dim_map, dless, dnan, Dim
 
 
 def calculate_y(expr01, x, y, terminals, add_coef=True, x_test=None, y_test=None,
-                filter_warning=True, inter_add=True, inner_add=False, vector_add=False, np_maps=None):
+                filter_warning=True, inter_add=True, inner_add=False, vector_add=False, out_add=False, flat_add=False,
+                np_maps=None):
     if filter_warning:
         warnings.filterwarnings("ignore")
     try:
@@ -35,7 +36,7 @@ def calculate_y(expr01, x, y, terminals, add_coef=True, x_test=None, y_test=None
             pre_y, expr01 = try_add_coef(expr01, x, y, terminals,
                                          filter_warning=filter_warning,
                                          inter_add=inter_add, inner_add=inner_add,
-                                         vector_add=vector_add, np_maps=np_maps)
+                                         vector_add=vector_add, out_add=out_add, flat_add=flat_add, np_maps=np_maps)
         else:
             func0 = sympy.utilities.lambdify(terminals, expr01, modules=[np_maps, "numpy"])
             pre_y = func0(*x)
@@ -83,7 +84,7 @@ def uniform_score(score_pen=1):
 
 def calculate_score(expr01, x, y, terminals, scoring=None, score_pen=(1,),
                     add_coef=True, filter_warning=True, inter_add=True,
-                    inner_add=False, vector_add=False, np_maps=None):
+                    inner_add=False, vector_add=False, out_add=False, flat_add=False, np_maps=None):
     """
 
     Parameters
@@ -136,7 +137,7 @@ def calculate_score(expr01, x, y, terminals, scoring=None, score_pen=(1,),
 
     pre_y, expr01 = calculate_y(expr01, x, y, terminals, add_coef=add_coef,
                                 filter_warning=filter_warning, inter_add=inter_add, inner_add=inner_add,
-                                vector_add=vector_add,
+                                vector_add=vector_add, out_add=out_add, flat_add=flat_add,
                                 np_maps=np_maps)
 
     try:
@@ -156,7 +157,7 @@ def calculate_score(expr01, x, y, terminals, scoring=None, score_pen=(1,),
 
 def calculate_cv_score(expr01, x, y, terminals, scoring=None, score_pen=(1,), cv=5, refit=True,
                        add_coef=True, filter_warning=True, inter_add=True,
-                       inner_add=False, vector_add=False, np_maps=None):
+                       inner_add=False, vector_add=False, out_add=False, flat_add=False, np_maps=None):
     """
     use cv spilt for score,return the mean_test_score.
     use cv spilt for predict,return the cv_predict_y.(not be used)
@@ -165,6 +166,7 @@ def calculate_cv_score(expr01, x, y, terminals, scoring=None, score_pen=(1,), cv
         Thus the expression is not compact with the this scores, when re-calculated by this expression
     Parameters
     ----------
+
     refit: True:
         use forced, refit the coefficient use all data.
     cv:sklearn.model_selection._split._BaseKFold,int
@@ -192,6 +194,10 @@ def calculate_cv_score(expr01, x, y, terminals, scoring=None, score_pen=(1,), cv
         bool
     inner_add: bool
         bool
+    flat_add:bool
+        bool
+    out_add:bool
+        bool
     np_maps: Callable
         user np.ndarray function
 
@@ -210,7 +216,8 @@ def calculate_cv_score(expr01, x, y, terminals, scoring=None, score_pen=(1,), cv
     if cv == 1:
         sc_all, expr01, pre_y = calculate_score(expr01, x, y, terminals, scoring=scoring, score_pen=score_pen,
                                                 add_coef=add_coef, filter_warning=filter_warning, inter_add=inter_add,
-                                                inner_add=inner_add, vector_add=vector_add, np_maps=np_maps)
+                                                inner_add=inner_add, vector_add=vector_add, out_add=out_add,
+                                                flat_add=flat_add, np_maps=np_maps)
         return sc_all, expr01, pre_y
 
     if isinstance(cv, int):
@@ -243,7 +250,7 @@ def calculate_cv_score(expr01, x, y, terminals, scoring=None, score_pen=(1,), cv
                                     add_coef=add_coef,
                                     filter_warning=filter_warning, inter_add=inter_add,
                                     inner_add=inner_add,
-                                    vector_add=vector_add,
+                                    vector_add=vector_add, out_add=out_add, flat_add=flat_add,
                                     np_maps=np_maps)
 
         try:
@@ -272,7 +279,8 @@ def calculate_cv_score(expr01, x, y, terminals, scoring=None, score_pen=(1,), cv
         "the refit only use for see the detial of calcualtion after loop"
         sc_all0, expr01, pre_y0 = calculate_score(expr01, x, y, terminals, scoring=scoring, score_pen=score_pen,
                                                   add_coef=add_coef, filter_warning=filter_warning, inter_add=inter_add,
-                                                  inner_add=inner_add, vector_add=vector_add, np_maps=np_maps)
+                                                  inner_add=inner_add, vector_add=vector_add, out_add=out_add,
+                                                  flat_add=flat_add, np_maps=np_maps)
 
     return sc_all, expr01, pre_y
 
@@ -372,14 +380,15 @@ def calculate_collect(ind, context, x, y, terminals_and_constants_repr, gro_ter_
                       dim_ter_con_list, dim_type, fuzzy, cv=1, refit=True,
                       scoring=None, score_pen=(1,),
                       add_coef=True, filter_warning=True, inter_add=True, inner_add=False,
-                      vector_add=False,
+                      vector_add=False, out_add=False, flat_add=False,
                       np_maps=None, dim_maps=None, cal_dim=True):
     expr01 = compile_context(ind, context, gro_ter_con)
 
     score, expr01, pre_y = calculate_cv_score(expr01, x, y, terminals_and_constants_repr,
                                               cv=cv, refit=refit,
                                               add_coef=add_coef, inter_add=inter_add,
-                                              inner_add=inner_add, vector_add=vector_add,
+                                              inner_add=inner_add, vector_add=vector_add, out_add=out_add,
+                                              flat_add=flat_add,
                                               scoring=scoring, score_pen=score_pen,
                                               filter_warning=filter_warning,
                                               np_maps=np_maps)
