@@ -37,9 +37,9 @@ class BaseLoop(Toolbox):
     def __init__(self, pset, pop=500, gen=20, mutate_prob=0.5, mate_prob=0.8, hall=1, re_hall=None,
                  re_Tree=None, initial_min=None, initial_max=3, max_value=5,
                  scoring=(r2_score,), score_pen=(1,), filter_warning=True, cv=1,
-                 add_coef=True, inter_add=True, inner_add=False, vector_add=False,
+                 add_coef=True, inter_add=True, inner_add=False, vector_add=False, out_add=False, flat_add=False,
                  cal_dim=False, dim_type=None, fuzzy=False, n_jobs=1, batch_size=40,
-                 random_state=None, stats=None, verbose=True,
+                 random_state=None, stats=None, verbose=True, migrate_prob=0,
                  tq=True, store=False, personal_map=False, stop_condition=None):
         """
 
@@ -159,6 +159,7 @@ class BaseLoop(Toolbox):
         self.gen = gen
         self.mutate_prob = mutate_prob
         self.mate_prob = mate_prob
+        self.migrate_prob = migrate_prob
         self.verbose = verbose
         self.cal_dim = cal_dim
         self.re_hall = re_hall
@@ -171,7 +172,7 @@ class BaseLoop(Toolbox):
         self.cpset = CalculatePrecisionSet(pset, scoring=scoring, score_pen=score_pen,
                                            filter_warning=filter_warning, cal_dim=cal_dim,
                                            add_coef=add_coef, inter_add=inter_add, inner_add=inner_add,
-                                           vector_add=vector_add, cv=cv,
+                                           vector_add=vector_add, out_add=out_add, flat_add=flat_add, cv=cv,
                                            n_jobs=n_jobs, batch_size=batch_size, tq=tq,
                                            fuzzy=fuzzy, dim_type=dim_type,
                                            )
@@ -181,11 +182,11 @@ class BaseLoop(Toolbox):
         # def produce
         if initial_min is None:
             initial_min = 2
-        self.register("genGrow", genGrow, pset=self.cpset, min_=initial_min, max_=initial_max+1,
+        self.register("genGrow", genGrow, pset=self.cpset, min_=initial_min, max_=initial_max + 1,
                       personal_map=self.personal_map)
-        self.register("genFull", genFull, pset=self.cpset, min_=initial_min, max_=initial_max+1,
+        self.register("genFull", genFull, pset=self.cpset, min_=initial_min, max_=initial_max + 1,
                       personal_map=self.personal_map)
-        self.register("gen_mu", genGrow, min_=1, max_=2+1, personal_map=self.personal_map)
+        self.register("gen_mu", genGrow, min_=1, max_=1 + 1, personal_map=self.personal_map)
         # def selection
 
         self.register("select", selTournament, tournsize=2)
@@ -199,8 +200,8 @@ class BaseLoop(Toolbox):
 
         self.register("mutate", mutUniform, expr=self.gen_mu, pset=self.cpset)
 
-        self.decorate("mate", staticLimit(key=operator.attrgetter("height"), max_value=2 * (max_value+1)))
-        self.decorate("mutate", staticLimit(key=operator.attrgetter("height"), max_value=2 * (max_value+1)))
+        self.decorate("mate", staticLimit(key=operator.attrgetter("height"), max_value=2 * (max_value + 1)))
+        self.decorate("mutate", staticLimit(key=operator.attrgetter("height"), max_value=2 * (max_value + 1)))
 
         if stats is None:
             if cal_dim:
@@ -346,13 +347,14 @@ class BaseLoop(Toolbox):
                 if self.stop_condition(self.hall.items[0]):
                     break
             # 6.next generation#######################################################
-            # selection and mutate,mate
-            population = self.select(population, len(population) - len(inds_dim))
+            # selection and mutate,mate,migration
+            population = self.select(population, int((1 - self.migrate_prob) * len(population)) - len(inds_dim))
 
             offspring = self.varAnd(population, self, self.mate_prob, self.mutate_prob)
 
             offspring.extend(inds_dim)
-            population[:] = offspring
+            migrate_pop = [self.PTree(self.genFull()) for _ in range(int(self.migrate_prob * len(population)))]
+            population[:] = offspring + migrate_pop
 
         # 7.store#####################################################################
 
@@ -443,6 +445,7 @@ class DimForceLoop(MutilMutateLoop):
         self.register("select", selKbestDim,
                       dim_type=self.cpset.dim_type, fuzzy=self.cpset.fuzzy, force_number=True)
 
+
 if __name__ == "__main__":
     # data
     data = load_boston()
