@@ -17,7 +17,7 @@ class SymbolLearning(BaseEstimator, MultiOutputMixin, TransformerMixin):
     def __str__(self):
         return str(self.loop)
 
-    def __init__(self, *args, loop=None, **kwargs):
+    def __init__(self, loop, *args, **kwargs):
         """
         Parameters
         ----------
@@ -71,7 +71,11 @@ class SymbolLearning(BaseEstimator, MultiOutputMixin, TransformerMixin):
         inter_add：bool
             add intercept constant or not
         inner_add:bool
-            dd inner coeffcients or not
+            add inner coeffcients or not
+        out_add:bool
+            add out coeffcients or not
+        flat_add:bool
+            add flat coeffcients or not
         n_jobs:int
             default 1, advise 6
         batch_size:int
@@ -161,12 +165,28 @@ class SymbolLearning(BaseEstimator, MultiOutputMixin, TransformerMixin):
             See Also SymbolSet
 
         """
+        # try to find pest form args,kwargs
+        psets = [i for i in self.args if isinstance(i, SymbolSet)]
+        if len(psets) > 0:
+            self.args.remove(psets[0])
+        if "pset" in self.kwargs:
+            psets.append(self.kwargs["pset"])
+            del self.kwargs["pset"]
+
         if pset is None:
-            pset = SymbolSet()
-            pset.add_features_and_constants(X, y, c, x_dim=1, y_dim=1, c_dim=1, x_prob=None,
-                                            c_prob=None, x_group=x_group, feature_name=None)
-            pset.add_operations(power_categories=(2, 3, 0.5),
-                                categories=("Add", "Mul", "Sub", "Div"))
+            if len(psets) > 0:
+                pset = psets[0]
+
+        if pset is None:
+            # one simple pset are generate with no dimension calculation, But just with x_group.\n
+            if X is not None and y is not None:
+                pset = SymbolSet()
+                pset.add_features_and_constants(X, y, c, x_dim=1, y_dim=1, c_dim=1, x_prob=None,
+                                                c_prob=None, x_group=x_group, feature_name=None)
+                pset.add_operations(power_categories=(2, 3, 0.5),
+                                    categories=("Add", "Mul", "Sub", "Div"))
+            else:
+                raise ValueError("The pset should be defined or the X and Y should be offered.")
 
         self.loop = self.loop(pset, *self.args, **self.kwargs)
         hall = self.loop.run()
@@ -214,8 +234,6 @@ class SymbolLearning(BaseEstimator, MultiOutputMixin, TransformerMixin):
 
     def score(self, X, y, scoring):
 
-        y_pred = self.predict(X)
-
         scoring = check_scoring(self, scoring=scoring)
 
         if not isinstance(scoring, (list, tuple)):
@@ -223,7 +241,7 @@ class SymbolLearning(BaseEstimator, MultiOutputMixin, TransformerMixin):
         try:
             sc_all = []
             for si in scoring:
-                sc = si(self, y, y_pred)
+                sc = si(self, X, y)
                 sc_all.append(sc)
 
         except (ValueError, RuntimeWarning):
